@@ -5,6 +5,7 @@ import (
 	"os"
 	"path/filepath"
 	"runtime"
+
 	"strings"
 
 	"github.com/aquasecurity/tfsec/pkg/result"
@@ -24,6 +25,7 @@ import (
 
 	"github.com/spf13/cobra"
 
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/metrics"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/parser"
 	_ "github.com/aquasecurity/tfsec/internal/app/tfsec/rules"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
@@ -226,6 +228,10 @@ var rootCmd = &cobra.Command{
 			results = filteredResult
 		}
 
+		for _, result := range results {
+			metrics.AddResult(result.Severity)
+		}
+
 		if runStatistics {
 			statistics := scanner.Statistics{}
 			for _, result := range results {
