@@ -19,10 +19,11 @@ import (
 )
 
 var severityFormat = map[severity.Severity]string{
-	severity.Low:    tml.Sprintf("<white>%s</white>", severity.Low),
-	severity.Medium: tml.Sprintf("<yellow>%s</yellow>", severity.Medium),
-	severity.High:   tml.Sprintf("<red>%s</red>", severity.High),
-	"":              tml.Sprintf("<white>%s</white>", severity.Low),
+	severity.Low:      tml.Sprintf("<white>%s</white>", severity.Low),
+	severity.Medium:   tml.Sprintf("<yellow>%s</yellow>", severity.Medium),
+	severity.High:     tml.Sprintf("<red>%s</red>", severity.High),
+	severity.Critical: tml.Sprintf("<bold><red>%s</red></bold>", severity.Critical),
+	"":                tml.Sprintf("<white>UNKNOWN</white>"),
 }
 
 func FormatDefault(_ io.Writer, results []result.Result, _ string, options ...FormatterOption) error {
@@ -103,6 +104,7 @@ func printResult(res result.Result, i int, includePassedChecks bool) {
 }
 
 func printStatistics() {
+
 	metrics.Add(metrics.FilesLoaded, parser.CountFiles())
 
 	_ = tml.Printf("  <blue>times</blue>\n  ------------------------------------------\n")
@@ -115,8 +117,9 @@ func printStatistics() {
 	} {
 		_ = tml.Printf("  <blue>%-20s</blue> %s\n", operation, times[operation].String())
 	}
-	counts := metrics.CountSummary()
+
 	_ = tml.Printf("\n  <blue>counts</blue>\n  ------------------------------------------\n")
+	counts := metrics.CountSummary()
 	for _, name := range []metrics.Count{
 		metrics.FilesLoaded,
 		metrics.BlocksLoaded,
@@ -127,6 +130,17 @@ func printStatistics() {
 	} {
 		_ = tml.Printf("  <blue>%-20s</blue> %d\n", name, counts[name])
 	}
+
+	_ = tml.Printf("\n  <blue>results</blue>\n  ------------------------------------------\n")
+	for _, sev := range []severity.Severity{
+		severity.Critical,
+		severity.High,
+		severity.Medium,
+		severity.Low,
+	} {
+		count := metrics.CountSeverity(sev)
+		_ = tml.Printf("  <blue>%-20s</blue> %d\n", strings.ToLower(string(sev)), count)
+	}
 }
 
 // highlight the lines of code which caused a problem, if available
