@@ -5,19 +5,19 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/tfsec/tfsec/pkg/severity"
+	"github.com/aquasecurity/tfsec/pkg/severity"
 
-	"github.com/tfsec/tfsec/pkg/result"
+	"github.com/aquasecurity/tfsec/pkg/result"
 
-	"github.com/tfsec/tfsec/pkg/provider"
+	"github.com/aquasecurity/tfsec/pkg/provider"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/hclcontext"
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/block"
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 
-	"github.com/tfsec/tfsec/pkg/rule"
+	"github.com/aquasecurity/tfsec/pkg/rule"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/scanner"
+	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
 )
 
 const AWSKMSManagedPoliciesShouldNotAllowDecryptionActionsOnAllKMSKeys = "AWS097"
@@ -105,9 +105,14 @@ type awsIAMPolicyDocument struct {
 }
 
 type awsIAMPolicyDocumentStatement struct {
-	Effect   string                    `json:"Effect"`
-	Action   awsIAMPolicyDocumentValue `json:"Action"`
-	Resource awsIAMPolicyDocumentValue `json:"Resource,omitempty"`
+	Effect    string                    `json:"Effect"`
+	Action    awsIAMPolicyDocumentValue `json:"Action"`
+	Resource  awsIAMPolicyDocumentValue `json:"Resource,omitempty"`
+	Principal awsIAMPolicyPrincipal     `json:"Principal,omitempty"`
+}
+
+type awsIAMPolicyPrincipal struct {
+	AWS awsIAMPolicyDocumentValue `json:"AWS"`
 }
 
 // AWS allows string or []string as value, we convert everything to []string to avoid casting
@@ -157,7 +162,7 @@ func init() {
 		Provider:        provider.AWSProvider,
 		RequiredTypes:   []string{"resource"},
 		RequiredLabels:  []string{"aws_iam_policy", "aws_iam_group_policy", "aws_iam_user_policy", "aws_iam_role_policy"},
-		DefaultSeverity: severity.Error,
+		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, ctx *hclcontext.Context) {
 
 			policyAttr := resourceBlock.GetAttribute("policy")
@@ -191,11 +196,10 @@ func init() {
 						if resources := statementBlock.GetAttribute("resources"); resources != nil {
 							if resources.Contains("*") {
 								set.Add(
-									result.New(resourceBlock).
-										WithDescription(fmt.Sprintf("Resource '%s' a policy with KMS actions for all KMS keys.", resourceBlock.FullName())).
+									result.New(policyDocumentBlock).
+										WithDescription(fmt.Sprintf("Resource '%s' a policy with KMS actions for all KMS keys.", policyDocumentBlock.FullName())).
 										WithRange(resources.Range()).
-										WithAttributeAnnotation(resources).
-										WithSeverity(severity.Error),
+										WithAttributeAnnotation(resources),
 								)
 							}
 						}
@@ -225,8 +229,7 @@ func checkAWS097PolicyJSON(set result.Set, resourceBlock block.Block, policyAttr
 						result.New(resourceBlock).
 							WithDescription(fmt.Sprintf("Resource '%s' a policy with KMS actions for all KMS keys.", resourceBlock.FullName())).
 							WithRange(policyAttr.Range()).
-							WithAttributeAnnotation(policyAttr).
-							WithSeverity(severity.Error),
+							WithAttributeAnnotation(policyAttr),
 					)
 					return
 				}
